==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/MedianPriceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { MedianPriceIndicatorDescription } from "./MedianPriceIndicatorDescription";
/**
 * @hidden
 */
export let MedianPriceIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MedianPriceIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MedianPriceIndicatorDescriptionMetadata.a == null) {
                MedianPriceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MedianPriceIndicatorDescriptionMetadata.c(MedianPriceIndicatorDescriptionMetadata.a);
            }
            if (a.j(MedianPriceIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(MedianPriceIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MedianPriceIndicatorDescriptionMetadata.b(a);
            a.aa("MedianPriceIndicator", () => new MedianPriceIndicatorDescription());
            a.z("MedianPriceIndicator", MedianPriceIndicatorDescriptionMetadata.a);
        }
    }
    MedianPriceIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(MedianPriceIndicatorDescriptionMetadata, 'MedianPriceIndicatorDescriptionMetadata');
    MedianPriceIndicatorDescriptionMetadata.a = null;
    return MedianPriceIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/MedianPriceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { MedianPriceIndicatorDescription } from "./MedianPriceIndicatorDescription";
/**
 * @hidden
 */
export let MedianPriceIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MedianPriceIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MedianPriceIndicatorDescriptionMetadata.a == null) {
                MedianPriceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MedianPriceIndicatorDescriptionMetadata.c(MedianPriceIndicatorDescriptionMetadata.a);
            }
            if (a.k(MedianPriceIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(MedianPriceIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MedianPriceIndicatorDescriptionMetadata.b(a);
            a.ac("MedianPriceIndicator", () => new MedianPriceIndicatorDescription());
            a.ab("MedianPriceIndicator", MedianPriceIndicatorDescriptionMetadata.a);
        }
    }
    MedianPriceIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(MedianPriceIndicatorDescriptionMetadata, 'MedianPriceIndicatorDescriptionMetadata');
    MedianPriceIndicatorDescriptionMetadata.a = null;
    return MedianPriceIndicatorDescriptionMetadata;
})();
